local sti = require("sti")

function love.load()
  -- Get the window size
  windowWidth, windowHeight = love.window.getMode()
  
  -- Load the map - this is just a test map with only one tile layer
  map = sti.new("maps/map01")
  
  -- Set the physics properties
  love.physics.setMeter(32)
  world = love.physics.newWorld(0*love.physics.getMeter(), 0*love.physics.getMeter())
  
  -- Place the player in the centre of the window
  player_init_x = (windowWidth/2) - (love.physics.getMeter()/2)
  player_init_y = (windowHeight/2) - (love.physics.getMeter()/2)
  
  -- Add a layer for sprites - at this time this will only be the player
  map:addCustomLayer("Sprite Layer", 2)
  local sprite_layer = map.layers["Sprite Layer"]
  -- Add the player to the layer
  sprite_layer.sprites = {
    player = {
      image = love.graphics.newImage("player.png"),
      x = player_init_x,
      y = player_init_y,
      r = 0,
    }
  }
  
  -- Place holder for updating the player
  function sprite_layer:update(dt)
    for _, sprite in pairs(self.sprites) do
      -- 
    end
  end

  -- Draw each sprite
  function sprite_layer:draw()
    for _, sprite in pairs(self.sprites) do
      local x = math.floor(sprite.x)
      local y = math.floor(sprite.y)
      local r = sprite.r
      love.graphics.draw(sprite.image, x, y, r)
    end
  end
end

function love.update(dt)
  local p = map.layers["Sprite Layer"].sprites["player"]
  -- Move player sprite if wasd buttons are pressed
  -- Speed manually set here at 5 tiles per second
  if love.keyboard.isDown('w') then p.y = p.y - love.physics.getMeter()*dt*5; end
  if love.keyboard.isDown('s') then p.y = p.y + love.physics.getMeter()*dt*5; end
  if love.keyboard.isDown('a') then p.x = p.x - love.physics.getMeter()*dt*5; end
  if love.keyboard.isDown('d') then p.x = p.x + love.physics.getMeter()*dt*5; end
  
  map:update(dt)
end

function love.draw()
  local player = map.layers["Sprite Layer"].sprites["player"]
  -- Translate the graphics in the opposite direction to the players movement
  love.graphics.translate(-(player.x-player_init_x), -(player.y-player_init_y))
  -- Only draw the required tiles
  map:setDrawRange(player.x-player_init_x, player.y-player_init_y, windowWidth, windowWidth)
  map:draw()
  
  -- Reset colour
  love.graphics.setColor(0, 0, 0, 255)
  -- Print the players location in the top left corner, for debugging purposes
  love.graphics.print(math.floor(player.x)..", "..math.floor(player.y), 20+player.x-player_init_x, 20+player.y-player_init_y)
end